yt.data\_objects.static\_output module
======================================

.. automodule:: yt.data_objects.static_output
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:
